Module config

Module config 

A global configuration of types for device code.

We are defining the field element and extension element as type aliases rather than using generics in order to avoid complicated trait bounds but remain flexible enough to support different field and extension element types.

Type Aliases

Ext
The extension field element type.
Felt
The base field element type.
TestGC
The most common GC, used for testing.