Module traces

Module traces 

Structs

AbstractChipLayout
Abstract description of a chip layout used to build TraceDenseData / JaggedTraceMle. Each tuple is(chip_name, preprocessed_width, main_width) for one chip;
AbstractChipLayoutWithHeights
Like AbstractChipLayout, but with a per-chip row count attached to each entry. Each tuple is (chip_name, preprocessed_width, main_width, height) for one chip.
JaggedTraceMle
TraceDenseData
Jagged representation of the traces.
TraceDenseDataMutRaw
The raw pointer to the dense data, for use in CUDA FFI calls.
TraceDenseDataRaw
The raw pointer to the dense data, for use in CUDA FFI calls.
TraceOffset