JaggedTraceMle

Struct JaggedTraceMle 

pub struct JaggedTraceMle<F: Field, B: Backend>(pub JaggedMle<TraceDenseData<F, B>, B>);

Tuple Fields

0: JaggedMle<TraceDenseData<F, B>, B>

Implementations

Source

impl<F: Field, B: Backend> JaggedTraceMle<F, B>

pub fn new( dense_data: TraceDenseData<F, B>, col_index: Buffer<u32, B>, start_indices: Buffer<u32, B>, column_heights: Vec<u32>, ) -> Self

Source

impl<F: Field> JaggedTraceMle<F, CpuBackend>

pub fn from_chip_layout( dense: Buffer<F, CpuBackend>, layout: &AbstractChipLayoutWithHeights, log_stacking_height: u32, ) -> Self

Build a JaggedTraceMle over a pre-allocated dense buffer using a chip-layout description as parallel slices. Constructs the inner TraceDenseData with the same layout as TraceDenseData::from_chip_layout, plus the jagged column metadata: one logical column per chip column for both preprocessed and main, plus one padding column per section that has nonzero padding.

All heights must be even, since column heights and column-index entries are stored at half-element granularity.

Source

impl<F: Field> JaggedTraceMle<F, TaskScope>

pub fn preprocessed_virtual_tensor( &self, log_stacking_height: u32, ) -> TensorView<'_, F, TaskScope>

pub fn main_virtual_tensor( &self, log_stacking_height: u32, ) -> TensorView<'_, F, TaskScope>

pub fn main_poly_height(&self, name: &str) -> Option<usize>

pub fn preprocessed_poly_height(&self, name: &str) -> Option<usize>

pub fn main_num_polys(&self, name: &str) -> Option<usize>

pub fn main_size(&self) -> usize

pub fn preprocessed_num_polys(&self, name: &str) -> Option<usize>

Source

impl<F: Field> JaggedTraceMle<F, CpuBackend>

Source

impl<F: Field> JaggedTraceMle<F, TaskScope>

Methods from Deref<Target = JaggedMle<TraceDenseData<F, B>, B>>

pub fn as_raw(&self) -> JaggedMleRaw<D, A>

pub fn as_mut_raw(&mut self) -> JaggedMleMutRaw<D, A>
where D: DenseDataMut<A>,

pub fn dense(&self) -> &D

pub fn dense_mut(&mut self) -> &mut D

pub fn col_index(&self) -> &Buffer<u32, A>

pub fn col_index_mut(&mut self) -> &mut Buffer<u32, A>

pub fn start_indices(&self) -> &Buffer<u32, A>

pub fn start_indices_mut(&mut self) -> &mut Buffer<u32, A>