TraceDenseData

Struct TraceDenseData 

pub struct TraceDenseData<F: Field, B: Backend> {
    pub dense: Buffer<F, B>,
    pub preprocessed_offset: usize,
    pub preprocessed_cols: usize,
    pub preprocessed_padding: usize,
    pub main_padding: usize,
    pub preprocessed_table_index: BTreeMap<String, TraceOffset>,
    pub main_table_index: BTreeMap<String, TraceOffset>,
}
Jagged representation of the traces.

Fields

dense: Buffer<F, B>

The dense representation of the traces.

preprocessed_offset: usize

The dense offset of the preprocessed traces.

preprocessed_cols: usize

The total number of columns in the preprocessed traces.

preprocessed_padding: usize

The amount of preprocessed padding, to the next multiple of 2^log_stacking_height.

main_padding: usize

The amount of main padding, to the next multiple of 2^log_stacking_height.

preprocessed_table_index: BTreeMap<String, TraceOffset>

A mapping from chip name to the range of dense data it occupies for preprocessed traces.

main_table_index: BTreeMap<String, TraceOffset>

A mapping from chip name to the range of dense data it occupies for main traces.

Implementations

Source

impl<F: Field, B: Backend> TraceDenseData<F, B>

pub fn main_virtual_tensor( &self, log_stacking_height: u32, ) -> TensorView<'_, F, B>

pub fn main_tensor(&self, log_stacking_height: u32) -> Tensor<F, B>

Copies the correct data from dense to a new tensor for main traces.

pub fn preprocessed_virtual_tensor( &self, log_stacking_height: u32, ) -> TensorView<'_, F, B>

pub fn preprocessed_tensor(&self, log_stacking_height: u32) -> Tensor<F, B>

Copies the correct data from dense to a new tensor for preprocessed traces.

pub fn main_poly_height(&self, name: &str) -> Option<usize>

The size of the main polynomial.

pub fn preprocessed_poly_height(&self, name: &str) -> Option<usize>

The size of the preprocessed polynomial.

pub fn main_num_polys(&self, name: &str) -> Option<usize>

The number of polynomials in the main trace.

pub fn main_size(&self) -> usize

The size of the main trace dense data, including padding.

pub fn preprocessed_num_polys(&self, name: &str) -> Option<usize>

The number of polynomials in the preprocessed trace.

Source

impl<F: Field> TraceDenseData<F, CpuBackend>

Source

impl<F: Field> TraceDenseData<F, TaskScope>