A global configuration of types for device code.
We are defining the field element and extension element as type aliases rather than using generics in order to avoid complicated trait bounds but remain flexible enough to support different field and extension element types.