Structs
- Abstract
Chip Layout - Abstract description of a chip layout used to build
TraceDenseData/JaggedTraceMle. Each tuple is(chip_name, preprocessed_width, main_width)for one chip; - Abstract
Chip Layout With Heights - Like
AbstractChipLayout, but with a per-chip row count attached to each entry. Each tuple is(chip_name, preprocessed_width, main_width, height)for one chip. - Jagged
Trace Mle - Trace
Dense Data - Jagged representation of the traces.
- Trace
Dense Data MutRaw - The raw pointer to the dense data, for use in CUDA FFI calls.
- Trace
Dense Data Raw - The raw pointer to the dense data, for use in CUDA FFI calls.
- Trace
Offset