Module traces

Module traces 

Structs

JaggedTraceMle
TraceDenseData
Jagged representation of the traces.
TraceDenseDataMutRaw
The raw pointer to the dense data, for use in CUDA FFI calls.
TraceDenseDataRaw
The raw pointer to the dense data, for use in CUDA FFI calls.
TraceOffset