Structs
- Jagged
Trace Mle - Trace
Dense Data - Jagged representation of the traces.
- Trace
Dense Data MutRaw - The raw pointer to the dense data, for use in CUDA FFI calls.
- Trace
Dense Data Raw - The raw pointer to the dense data, for use in CUDA FFI calls.
- Trace
Offset